pub fn copy_archive_to_zipfile<R: Read + Seek>(
src: &mut ZipDirArchive<R>,
dest: &mut File,
) -> Result<()>Expand description
Copy src, an already open archive, to dest, an already open file.
This utility takes an already open source archive and copies the contents into an already created destination file. The contents of the source are walked recursively to copy it entirely. The destination file is written to but remains open with the file cursor position unmodified after finishing writing the zip archive into the file. In other words, the file cursor remains at the end of the open file object.
Note that it is not necessary to use this function to create a zip archive which can be to opened later as a ZipDirArchive. This is because any zip file should also be readable by ZipDirArchive::from_zip().