copy_to_zip

Function copy_to_zip 

pub fn copy_to_zip<P1: AsRef<Path>, P2: AsRef<Path>>(
    src: P1,
    dest: P2,
) -> Result<()>
Copy source src (dir or zip) to a new zip at dest.

This is a high level utility that will open an existing source, which can be either a directory or a .zip file, and copy the contents into a newly created zip file. The contents of the source are walked recursively to copy it entirely.